/*
  Module  : main.c
  Purpose : Cool Notes
  Author  : kLoGraFX / Adam Kopacz <Adam.K@idnet.de>
            http://www.idnet.de/~AdamK

  This program is free software; you can redistribute it and/or modify it
  under the terms of the GNU General Public License as published by the
  Free Software Foundation; either version 2 of the license, or (at your
  option) any later version.

  This program is distributed in the hope that it will be useful, but
  WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General
  Public License for more details.
*/

#include "misc.h"





char *get_home()
{
 char * home = getenv("HOME");
 struct passwd * pw;
 if( home == NULL  || strlen(home) < 1)
  {
     pw = getpwuid(geteuid());
     if (pw == NULL)
     {
        fprintf(stderr, "cnotes: you don't have set $HOME and no passwd entry... you do not exist.");
        exit(1);
     }
    home = pw->pw_dir;
  }
 return(home);
}

void savePage(int nr, GtkWidget *text_name)
{
  FILE *f1;

  char *home = get_home();
  char *path = NULL;
  const char *buf;
  char *page_name = NULL;
  page_name  = gtk_object_get_data(GTK_OBJECT(text_name), "page_name");
  
  if((path = malloc(strlen(home) + strlen(CNOTES_HOME) + strlen("/note.XX") +10 +1+1)) == NULL)
  {
    fprintf(stderr, "cnotes: not enought memory (savePage)\n");
    exit(1);
  }

  /* saving text */
  sprintf(path, "%s/%snote.%02u", home, CNOTES_HOME, nr);
  
  f1 = fopen(path, "w");
  if(f1 == NULL)
  {
    fprintf(stderr, "cnotes: can't write %s\n", path);
    exit(1);
  }
  
  buf = gtk_editable_get_chars(GTK_EDITABLE(text_name), 0, -1);
  fprintf(f1, "%s", buf);
  fclose(f1);
  
  /*saving name */
  sprintf(path, "%s/%snote.%02u_name", home, CNOTES_HOME, nr);
  
  f1 = fopen(path, "w+");
  if(f1 == NULL)
  {
    fprintf(stderr, "cnotes: can't write %s\n", path);
    exit(1);
  }
  
  if(page_name)
    fprintf(f1, "%s\n", page_name);
  else 
    fprintf(f1, "new page\n");
  
  fclose(f1);
  free(path);
}

char *get_page_name(int nr)
{
 FILE *f;
 char *t = malloc(255);
 char *ret;
 char *home = get_home();
 char *path;
 
 if((path = malloc(strlen(home) + strlen(CNOTES_HOME) + strlen("/note.XX") +1+1)) == NULL)
 {
    fprintf(stderr, "cnotes: not enought memory (get_page_name)\n");
    exit(1);
 }
 
 sprintf(path, "%s/%snote.%02u_name", home, CNOTES_HOME, nr);
 f = fopen(path, "r");
 if(!f)return(NULL);
 fgets(t, 255, f);
 ret = malloc(strlen(t));
 bzero(ret, strlen(t));
 strncpy(ret, t, strlen(t)-1);
 free(t);
 free(path);
 fclose(f);
 return(ret);
}

 

void readPage(int nr, GtkWidget *text_name)
{
  FILE *f1;
  char *path = NULL;
  char *home = get_home();
  
  if((path = malloc(strlen(home) + strlen(CNOTES_HOME) + strlen("/note.XX") +1+1)) == NULL)
  {
    fprintf(stderr, "cnotes: not enought memory (readPage)\n");
    exit(1);
  }

  sprintf(path, "%s/%snote.%02u", home, CNOTES_HOME, nr);

  f1 = fopen(path, "r");
  if(f1 != NULL)
  {
    char *buffer = malloc(1024);
    int nchars;
    
    while (1)
    {
      nchars = fread(buffer, 1, 1024, f1);
      gtk_text_insert (GTK_TEXT (text_name), text_font, NULL,
                      NULL, buffer, nchars);

      if (nchars < 1024)
        break;
    }
    free(buffer);
    fclose (f1);
  }
  free(path);
}

void saveAll()
{
  int i;
  for(i=0;i<num_pages;i++)savePage(i,text[i]);
}

void delete (GtkWidget *widget, gpointer data)
{
  saveAll();
  gtk_main_quit();
}


GtkWidget *xpm_label_box (GtkWidget *parent, gchar **xpm_data, gchar *label_text, int i)
{
  GtkWidget *box;
  GtkWidget *label;
  GdkPixmap *pixmap;
  GdkBitmap *mask;
  GtkWidget *pixmapw;
  
  box = gtk_hbox_new (FALSE, 0);
  gtk_container_border_width (GTK_CONTAINER (box), 0);
  pixmap = gdk_pixmap_create_from_xpm_d (parent->window, &mask,
                                         &open_style->bg[GTK_STATE_NORMAL],
                                         xpm_data);
  pixmapw = gtk_pixmap_new (pixmap, mask);
  label = gtk_label_new (label_text);
  gtk_box_pack_start (GTK_BOX (box),
                     pixmapw, FALSE, FALSE, 2);
  gtk_box_pack_start (GTK_BOX (box), label, FALSE, FALSE, 2);
  gtk_widget_show(pixmapw);
  gtk_widget_show(label);
  if(i>=0)pixmapwid[i]=pixmapw;
  if(i>=0)xlabel[i]=label;
  return (box);
}

void do_rename()
{
  int page_nr = gtk_notebook_current_page(GTK_NOTEBOOK(notebook));
  char *temp;
  char *data;
  
  temp = gtk_entry_get_text (GTK_ENTRY (entry));
  data = malloc(strlen(temp)+1);
  bzero(data, strlen(temp)+1);
  strncpy(data, temp, strlen(temp));
  
  gtk_object_set_data(GTK_OBJECT(text[page_nr]), "page_name", data);
  gtk_label_set (GTK_LABEL(xlabel[page_nr]), data);  

  saveAll();

  gtk_widget_draw(GTK_WIDGET(notebook), NULL);
  gtk_widget_destroy(entry);
  gtk_widget_destroy(rename_window);
}

void rename_page()
{
  int page_nr;
  char *text;
  page_nr = gtk_notebook_current_page(GTK_NOTEBOOK(notebook));
  text = get_page_name(page_nr);

  rename_window = gtk_window_new (GTK_WINDOW_DIALOG);

  gtk_container_border_width (GTK_CONTAINER (rename_window), 10);
  gtk_window_set_policy(GTK_WINDOW(rename_window), TRUE, TRUE, TRUE);
  gtk_window_position  (GTK_WINDOW(rename_window), GTK_WIN_POS_CENTER);
  gtk_window_set_title (GTK_WINDOW(rename_window), "cnotes - rename");
  gtk_widget_realize(rename_window);

  misc_box = gtk_hbox_new (FALSE,0);
  gtk_container_add (GTK_CONTAINER (rename_window), misc_box);
  gtk_widget_show (misc_box);


  entry = gtk_entry_new ();
  if (text != NULL)
  {
    gtk_entry_set_text (GTK_ENTRY (entry), text);
  }else{
    gtk_entry_set_text (GTK_ENTRY (entry), "new page");
  }  
     
  gtk_box_pack_start(GTK_BOX (misc_box), entry, FALSE, FALSE, 4);
  gtk_entry_select_region (GTK_ENTRY (entry),0, GTK_ENTRY(entry)->text_length);
  gtk_widget_realize (entry);
  gtk_widget_show (entry);
  gtk_widget_grab_focus (entry);

  button = gtk_button_new_with_label(" Ok ");
  gtk_signal_connect(GTK_OBJECT(button), "clicked",
  			GTK_SIGNAL_FUNC(do_rename), NULL);
  gtk_widget_show(button);
  gtk_box_pack_end(GTK_BOX (misc_box), button, FALSE, FALSE, 4);
  gtk_widget_show (rename_window);
}

void delete_ok()
{
  char *path = NULL;
  char *home = get_home();
  
  saveAll();
  gtk_notebook_remove_page (GTK_NOTEBOOK(notebook), num_pages-1);
  gtk_widget_draw(GTK_WIDGET(notebook), NULL);

  if((path = malloc(strlen(home) + strlen(CNOTES_HOME) + strlen("/note.XX") +10 +1+1)) == NULL)
  {
    fprintf(stderr, "cnotes: not enought memory (readPage)\n");
    exit(1);
  }
  sprintf(path, "%s/%snote.%02u", home, CNOTES_HOME, num_pages-1);
  unlink(path);

  sprintf(path, "%s/%snote.%02u_name", home, CNOTES_HOME, num_pages-1);
  unlink(path);
  
  num_pages--;
  gtk_widget_destroy(del_window);
  free(path);
}

void delete_cancle()
{
  saveAll();
  gtk_widget_destroy(del_window);
}


void delete_page()
{
  char *text = get_page_name(num_pages-1);
  char *buf = malloc(1024);

  sprintf(buf, "Are you sure you want to remove\nyour last page (number: %d, name: %s)\nand all of the text in it?", num_pages, text);

  del_window = gtk_window_new (GTK_WINDOW_DIALOG);
  gtk_container_border_width (GTK_CONTAINER (del_window), 10);
  gtk_window_set_policy(GTK_WINDOW(del_window), TRUE, TRUE, TRUE);
  gtk_window_position  (GTK_WINDOW(del_window), GTK_WIN_POS_CENTER);
  gtk_window_set_title (GTK_WINDOW(del_window), "cnotes - delete");
  gtk_widget_realize(del_window);

  misc_box = gtk_vbox_new (FALSE,0);
  gtk_container_add (GTK_CONTAINER (del_window), misc_box);
  gtk_widget_show (misc_box);

  label = gtk_label_new(buf);
  gtk_box_pack_start(GTK_BOX (misc_box), label, FALSE, FALSE, 0);
  gtk_widget_show (label);

  separator = gtk_hseparator_new ();
  gtk_box_pack_start(GTK_BOX (misc_box), separator, FALSE, FALSE, 10);
  gtk_widget_show (separator);
  
  misc2_box = gtk_hbox_new (FALSE,0);
  gtk_container_add (GTK_CONTAINER (misc_box), misc2_box);
  gtk_widget_show (misc2_box);

  button = gtk_button_new_with_label(" Yes ");
  gtk_signal_connect(GTK_OBJECT(button), "clicked",
  			GTK_SIGNAL_FUNC(delete_ok), NULL);
  gtk_widget_show(button);			
  gtk_box_pack_start(GTK_BOX (misc2_box), button, FALSE, FALSE, 4);

  button = gtk_button_new_with_label(" No ");
  gtk_signal_connect(GTK_OBJECT(button), "clicked",
  			GTK_SIGNAL_FUNC(delete_cancle), NULL);
  gtk_widget_show(button);			
  gtk_box_pack_end(GTK_BOX (misc2_box), button, FALSE, FALSE, 4);

  gtk_widget_show (del_window);
}

void new_page()
{
 if(num_pages < MAX_PAGES-1)
 { 
  GtkWidget * box;
#ifdef WITH_SCROLLBARS
  GtkWidget *vscrollbar;
#endif
  GtkWidget * label_box;
  box = gtk_hbox_new (FALSE, 0);
  gtk_widget_show (box);
    
   text[num_pages] = gtk_text_new (NULL, NULL);
   gtk_object_set_data(GTK_OBJECT(text[num_pages]), "page_name", "new page");
   gtk_text_set_editable (GTK_TEXT (text[num_pages]), TRUE);
   gtk_text_set_word_wrap(GTK_TEXT (text[num_pages]), TRUE);
   gtk_widget_show (text[num_pages]);
#ifdef WITH_SCROLLBARS
  vscrollbar = gtk_vscale_new (GTK_TEXT (text[num_pages])->vadj);
  gtk_scale_set_draw_value(GTK_SCALE (vscrollbar), FALSE);
  gtk_widget_show (vscrollbar);
  gtk_box_pack_start (GTK_BOX (box), vscrollbar, FALSE, FALSE, 0);
#endif

  gtk_box_pack_start (GTK_BOX (box), text[num_pages], TRUE, TRUE, 10);
  label_box = xpm_label_box(window, book_closed_xpm, "new page", num_pages);
  gtk_notebook_insert_page (GTK_NOTEBOOK (notebook), box, label_box, num_pages);
  gtk_widget_realize (text[num_pages]);
  gtk_object_set_data(GTK_OBJECT(text[num_pages]), "page_name", "new page");

#ifdef WITH_TEXT_BG_COLOR
    gdk_window_set_background (GTK_TEXT (text[num_pages])->text_area, &text_background_color);
#endif

#ifdef WITH_TEXT_BG_IMAGE
    gdk_window_set_back_pixmap(GTK_TEXT(text[num_pages])->text_area, text_background_xpm, 0);
#endif

 readPage(num_pages, text[num_pages]);
 gtk_notebook_set_page (GTK_NOTEBOOK(notebook), num_pages);
 num_pages++;
 gtk_widget_draw(GTK_WIDGET(notebook), NULL);

 }else{
   fprintf(stderr,"cnotes: maximum page number reached\n");
 }
}


void clear_page (GtkWidget *widget, gint page_nr)
{
  guint len_of_text;

  page_nr = gtk_notebook_current_page(GTK_NOTEBOOK(notebook));

  len_of_text = gtk_text_get_length (GTK_TEXT (text[page_nr]));
  gtk_text_set_point (GTK_TEXT (GTK_TEXT (text[page_nr])), 0);
  gtk_text_forward_delete (GTK_TEXT (text[page_nr]), len_of_text);
 
}


static void page_switch (GtkWidget *parent, GtkNotebookPage *page, gint page_num)
{
  GtkNotebookPage *oldpage;
  GdkPixmap *pixmap_open;
  GdkPixmap *pixmap_closed;
  GdkBitmap *open_mask;
  GdkBitmap *closed_mask;
  int i;
  
  oldpage = GTK_NOTEBOOK(notebook)->cur_page;
  if (page == oldpage)return;

  pixmap_open = gdk_pixmap_create_from_xpm_d (parent->window, &open_mask,
                                         &open_style->bg[GTK_STATE_SELECTED],
					 book_open_xpm);

  pixmap_closed = gdk_pixmap_create_from_xpm_d (parent->window, &closed_mask,
                                         &closed_style->bg[GTK_STATE_NORMAL],
                                         book_closed_xpm);
  for(i=0;i<num_pages;i++)gtk_pixmap_set (GTK_PIXMAP(pixmapwid[i]), pixmap_closed, closed_mask);
  gtk_pixmap_set (GTK_PIXMAP (pixmapwid[page_num]), pixmap_open, open_mask);
  saveAll();
//  gtk_widget_grab_focus (text[page_num]);
}

void mkrcdir()
{
  char *home = get_home();
  char *path = NULL;

  if((path = malloc(strlen(home) + strlen(CNOTES_HOME)+1+1)) == NULL)
  {
    fprintf(stderr, "cnotes: not enought memory (mkrcdir)\n");
    exit(1);
  }

  sprintf(path, "%s/%s", home, CNOTES_HOME);
  mkdir(path,0700);
  free(path);
}


void insert_date(GtkWidget *widget, gint page_nr)
{
  char *data = NULL;
  time_t time_now;
  struct tm *xdate;

  time(&time_now);
  xdate = localtime(&time_now);

  if((data = malloc(10)) == NULL)
  {
    fprintf(stderr, "cnotes: not enought memory\n");
    exit(1);
  }
  sprintf(data, "%02d.%02d.%02d", xdate->tm_mday, xdate->tm_mon, xdate->tm_year);

  page_nr = gtk_notebook_current_page(GTK_NOTEBOOK(notebook));
  gtk_text_insert (GTK_TEXT (text[page_nr]), NULL, NULL, NULL, data, strlen(data));

}

void insert_time(GtkWidget *widget, gint page_nr)
{
  char *data = NULL;
  time_t time_now;
  struct tm *xdate;

  time(&time_now);
  xdate = localtime(&time_now);

  if((data = malloc(10)) == NULL)
  {
    fprintf(stderr, "cnotes: not enought memory\n");
    exit(1);
  }
  sprintf(data, "%02d:%02d", xdate->tm_hour, xdate->tm_min);

  page_nr = gtk_notebook_current_page(GTK_NOTEBOOK(notebook));
  gtk_text_insert (GTK_TEXT (text[page_nr]), NULL, NULL, NULL, data, strlen(data));
}


void set_background_image()
{
  FILE *f1;
  char *home = get_home();
  char *path = NULL;

  if((path = malloc(strlen(home) + strlen(CNOTES_HOME) +20 +1+1)) == NULL)
  {
    fprintf(stderr, "cnotes: not enought memory (set_background_image)\n");
    exit(1);
  }

  sprintf(path, "%s/%sbackground.xpm", home, CNOTES_HOME);

  f1 = fopen(path, "r");
  if(f1 == NULL)
  {
    if((background_xpm_path = malloc(strlen(PIXMAP_PATH) +20 +1+1)) == NULL)
    {
      fprintf(stderr, "cnotes: not enought memory (set_background_image)\n");
      exit(1);
    }
    
    sprintf(background_xpm_path,"%s/background.xpm",PIXMAP_PATH);
    background_xpm = gdk_pixmap_create_from_xpm   (window->window, &background_xpm_mask,
                                                  &open_style->bg[GTK_STATE_NORMAL],
                                                  background_xpm_path);
  }else{
    background_xpm = gdk_pixmap_create_from_xpm   (window->window, &background_xpm_mask,
                                                  &open_style->bg[GTK_STATE_NORMAL],
                                                  path);
  }
  gdk_window_set_back_pixmap(window->window,background_xpm, 0);
  gdk_window_set_back_pixmap(notebook->window,background_xpm, 0);
  free(path);
}

void set_text_background_image()
{
  FILE *f1;
  char *home = get_home();
  char *path = NULL;

  
  if((path = malloc(strlen(home) + strlen(CNOTES_HOME) +20 +1+1)) == NULL)
  {
    fprintf(stderr, "cnotes: not enought memory (set_text_background_image)\n");
    exit(1);
  }

  sprintf(path, "%s/%stext_background.xpm", home, CNOTES_HOME);

  f1 = fopen(path, "r");
  if(f1 == NULL)
  {
    if((text_background_xpm_path = malloc(strlen(PIXMAP_PATH) +20 +1+1)) == NULL)
    {
      fprintf(stderr, "cnotes: not enought memory (set_text_background_image)\n");
      exit(1);
    }
    
    sprintf(text_background_xpm_path,"%s/text_background.xpm",PIXMAP_PATH);
    text_background_xpm = gdk_pixmap_create_from_xpm (window->window, &text_background_xpm_mask,
                                                     &open_style->bg[GTK_STATE_NORMAL],
                                                     text_background_xpm_path);
  }else{
    text_background_xpm = gdk_pixmap_create_from_xpm (window->window, &text_background_xpm_mask,
                                                     &open_style->bg[GTK_STATE_NORMAL],
                                                     path);
  }
  free(path);
}


void show_help()
{
  GtkWidget *label_box;
  saveAll();
  
  if (help_show == 1)
  {
    gtk_notebook_remove_page (GTK_NOTEBOOK(notebook), num_pages);
    gtk_widget_draw(GTK_WIDGET(notebook), NULL);
    help_show = 0;
  }else{
  
    help_show = 1;
    fixed_font = gdk_font_load("-b&h-lucidatypewriter-medium-r-normal-*-*-120-*-*-m-*-iso8859-1");
    bold_big_font = gdk_font_load("-adobe-helvetica-bold-r-normal-*-*-180-*-*-p-*-iso8859-1");

    red_color.red   = 65535;
    red_color.green = 0;
    red_color.blue  = 0;

    if (!gdk_color_alloc(cmap, &red_color))
      fprintf(stderr, "cnotes: couldn't allocate color (red_color)\n");
    
    help_box = gtk_hbox_new (FALSE, 0);
    gtk_widget_show (help_box);
       
    help_text = gtk_text_new (NULL, NULL);
    gtk_text_set_editable (GTK_TEXT (help_text), FALSE);
    gtk_text_set_word_wrap(GTK_TEXT (help_text), TRUE);
    gtk_widget_show (help_text);

    help_scrollbar = gtk_vscale_new (GTK_TEXT (help_text)->vadj);
    gtk_scale_set_draw_value(GTK_SCALE (help_scrollbar), FALSE);
    gtk_widget_show (help_scrollbar);
    gtk_box_pack_start (GTK_BOX (help_box), help_scrollbar, FALSE, FALSE, 0);

    gtk_box_pack_start (GTK_BOX (help_box), help_text, TRUE, TRUE, 10);
    label_box = xpm_label_box(window, book_open_xpm, "Help", num_pages);
    gtk_notebook_insert_page (GTK_NOTEBOOK (notebook), help_box, label_box, num_pages);

    gtk_widget_realize (help_text);

    gtk_text_insert (GTK_TEXT (help_text), bold_big_font, &red_color, NULL, VERSION, strlen(VERSION));
    gtk_text_insert (GTK_TEXT (help_text), fixed_font, NULL, NULL, help_message, strlen(help_message));
    
    gtk_notebook_set_page (GTK_NOTEBOOK(notebook), num_pages);
    gtk_widget_draw(GTK_WIDGET(notebook), NULL);
  }
}




/*************************
         MAIN
*************************/

int main (int argc, char *argv[])
{
  int i;
  gtk_init (&argc, &argv);
  cmap = gdk_colormap_get_system();


#ifdef WITH_TEXT_BG_COLOR

#ifdef TEXT_BG_LIGHT_YELLOW
text_background_color.red   = 65535;
text_background_color.green = 65535;
text_background_color.blue  = 58326;
#endif

#ifdef TEXT_BG_LIGHT_GRAY
text_background_color.red   = 64066;
text_background_color.green = 64066;
text_background_color.blue  = 64066;
#endif

#ifdef TEXT_BG_WHITE
text_background_color.red   = 65535;
text_background_color.green = 65535;
text_background_color.blue  = 65535;
#endif

  if (!gdk_color_alloc(cmap, &text_background_color))
    fprintf(stderr, "cnotes: couldn't allocate color (text_background_color)\n");
#endif

  window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
  gtk_window_set_policy(GTK_WINDOW(window), TRUE, TRUE, FALSE);

  gtk_window_position  (GTK_WINDOW(window), GTK_WIN_POS_CENTER);	// center the window in the screen
  gtk_window_set_title (GTK_WINDOW(window), VERSION);			// set VERSION as title
  gtk_widget_set_name (window, "cnotes");
  gtk_widget_set_usize (window, 520, 300);				// width and height
  gtk_signal_connect (GTK_OBJECT (window), "delete_event",
                     GTK_SIGNAL_FUNC (delete), NULL);
  gtk_signal_connect (GTK_OBJECT (window), "destroy",
                     GTK_SIGNAL_FUNC (delete), NULL);
  gtk_container_border_width (GTK_CONTAINER (window), 2);
  gtk_widget_realize(window);
  gdk_window_set_icon_name (window->window, "cnotes");
  
  main_box = gtk_vbox_new (FALSE,0);
  gtk_container_add (GTK_CONTAINER (window), main_box);
  gtk_widget_show (main_box);
    
  notebook = gtk_notebook_new ();
  gtk_container_border_width (GTK_CONTAINER (notebook), 10);
  gtk_notebook_set_tab_pos (GTK_NOTEBOOK (notebook), GTK_POS_RIGHT);	// tab position. 
  gtk_box_pack_start (GTK_BOX(main_box),notebook,TRUE,TRUE,0);		// GTK_POS_TOP and so works too.
  gtk_widget_realize (notebook);

  closed_style = gtk_widget_get_style(notebook);			// for the background transparency
  open_style = gtk_widget_get_style(notebook);				// of the pixmaps

  icon = gdk_pixmap_create_from_xpm_d (window->window, &icon_mask,
                                    &closed_style->bg[GTK_STATE_NORMAL],
                                    icon_xpm);

  gdk_window_set_icon (window->window, NULL, icon, icon_mask);

#ifdef WITH_BAKGROUND_IMAGE
  set_background_image();
#endif

#ifdef WITH_TEXT_BG_IMAGE
  set_text_background_image();
#endif
  
  gtk_widget_show(notebook);

  bt_box = gtk_hbox_new (FALSE,0);
  gtk_box_pack_start (GTK_BOX(main_box), bt_box, FALSE, FALSE, 4);
  gtk_widget_show (bt_box);
    

/* font for text-widgets */

 text_font = gdk_font_load(TEXT_FONT);



/* edit buttons */


  misc2_box = gtk_hbox_new(FALSE,0);
  gtk_container_border_width (GTK_CONTAINER (misc2_box), 4);
  gtk_widget_show(misc2_box);
  gtk_box_pack_start (GTK_BOX (bt_box), misc2_box, FALSE, FALSE, 4);


/* clear button */

  button = gtk_button_new();
  gtk_signal_connect (GTK_OBJECT (button), "clicked",
                     GTK_SIGNAL_FUNC (clear_page),NULL);
  gtk_widget_show (button);
  misc_box = xpm_label_box(window, clear_xpm, "clear", -1);
  gtk_widget_show(misc_box);
  gtk_container_add (GTK_CONTAINER (button), misc_box);
  gtk_box_pack_start (GTK_BOX (misc2_box), button, FALSE, FALSE, 2);


/* date button */

  button = gtk_button_new();
  gtk_signal_connect (GTK_OBJECT (button), "clicked",
                     GTK_SIGNAL_FUNC (insert_date),NULL);
  gtk_widget_show (button);
  misc_box = xpm_label_box(window, cal_xpm, "date", -1);
  gtk_widget_show(misc_box);
  gtk_container_add (GTK_CONTAINER (button), misc_box);
  gtk_box_pack_start (GTK_BOX (misc2_box), button, FALSE, FALSE, 2);


/* time button */

  button = gtk_button_new();
  gtk_signal_connect (GTK_OBJECT (button), "clicked",
                     GTK_SIGNAL_FUNC (insert_time),NULL);
  gtk_widget_show (button);
  misc_box = xpm_label_box(window, clock_xpm, "time", -1);
  gtk_widget_show(misc_box);
  gtk_container_add (GTK_CONTAINER (button), misc_box);
  gtk_box_pack_start (GTK_BOX (misc2_box), button, FALSE, FALSE, 2);


/* page buttons */

  misc2_box = gtk_hbox_new(FALSE,0);
  gtk_container_border_width (GTK_CONTAINER (misc2_box), 4);
  gtk_widget_show(misc2_box);
  gtk_box_pack_start (GTK_BOX (bt_box), misc2_box, FALSE, FALSE, 4);

/* Add button */

  button = gtk_button_new();
  gtk_signal_connect(GTK_OBJECT(button), "clicked",
  			GTK_SIGNAL_FUNC(new_page), NULL);
  misc_box = xpm_label_box(window, add_xpm, "add", -1);
  gtk_widget_show(misc_box);
  gtk_container_add (GTK_CONTAINER (button), misc_box);
  gtk_widget_show(button);			
  gtk_box_pack_start (GTK_BOX (misc2_box), button, FALSE, FALSE, 2);

/* Delete button */

  button = gtk_button_new();
  gtk_signal_connect(GTK_OBJECT(button), "clicked",
  			GTK_SIGNAL_FUNC(delete_page), NULL);
  misc_box = xpm_label_box(window, delete_xpm, "del", -1);
  gtk_widget_show(misc_box);
  gtk_container_add (GTK_CONTAINER (button), misc_box);
  gtk_widget_show(button);			
  gtk_box_pack_start (GTK_BOX (misc2_box), button, FALSE, FALSE, 2);

/* Rename button */

  button = gtk_button_new();
  gtk_signal_connect(GTK_OBJECT(button), "clicked",
  			GTK_SIGNAL_FUNC(rename_page), NULL);
  misc_box = xpm_label_box(window, rename_xpm, "rename", -1);
  gtk_widget_show(misc_box);
  gtk_container_add (GTK_CONTAINER (button), misc_box);
  gtk_widget_show(button);			
  gtk_box_pack_start (GTK_BOX (misc2_box), button, FALSE, FALSE, 2);


/* cnotes (main) buttons */

  misc2_box = gtk_hbox_new(FALSE,0);
  gtk_container_border_width (GTK_CONTAINER (misc2_box), 4);
  gtk_widget_show(misc2_box);
//  gtk_container_add (GTK_CONTAINER (bt_box), misc2_box);
  gtk_box_pack_end (GTK_BOX (bt_box), misc2_box, FALSE, FALSE, 4);


/* exit button */
    
  button = gtk_button_new();
  gtk_signal_connect (GTK_OBJECT (button), "clicked",
                     GTK_SIGNAL_FUNC (delete), NULL);
  misc_box = xpm_label_box(window, exit_xpm, "exit", -1);
  gtk_widget_show(misc_box);
  gtk_container_add (GTK_CONTAINER (button), misc_box);
  gtk_box_pack_end (GTK_BOX(misc2_box), button, FALSE, FALSE, 2);
  gtk_widget_show (button);

/* help button */

  button = gtk_button_new();
  gtk_signal_connect (GTK_OBJECT (button), "clicked",
                     GTK_SIGNAL_FUNC (show_help),NULL);

  misc_box = xpm_label_box(window, help_xpm, "help", -1);
  gtk_widget_show(misc_box);
  gtk_container_add (GTK_CONTAINER (button), misc_box);
  gtk_box_pack_end (GTK_BOX(misc2_box), button, FALSE, FALSE, 2);
  gtk_widget_show (button);

    
/*** create the Pages  **********************************************************/

  for(i=0;i<MAX_PAGES-1;i++)
  {
   char * name = get_page_name(i);
   GtkWidget * box;
#ifdef WITH_SCROLLBARS
   GtkWidget *vscrollbar;
#endif
   GtkWidget * label_box;
   box= gtk_hbox_new (FALSE, 0);
   gtk_widget_show (box);
    
   if(!name)break;
     
   text[i] = gtk_text_new (NULL, NULL);
   gtk_object_set_data(GTK_OBJECT(text[i]), "page_name", name);
   gtk_text_set_editable (GTK_TEXT (text[i]), TRUE);
   gtk_text_set_word_wrap(GTK_TEXT (text[i]), TRUE);
   gtk_widget_show (text[i]);
   GTK_WIDGET_SET_FLAGS (text[i], GTK_CAN_DEFAULT);
   gtk_widget_grab_default (text[i]); //bla

#ifdef WITH_SCROLLBARS
  vscrollbar = gtk_vscale_new (GTK_TEXT (text[i])->vadj);
  gtk_scale_set_draw_value(GTK_SCALE (vscrollbar), FALSE);
  gtk_widget_show (vscrollbar);
  gtk_box_pack_start (GTK_BOX (box), vscrollbar, FALSE, FALSE, 0);
#endif

  gtk_box_pack_start (GTK_BOX (box), text[i], TRUE, TRUE, 10);
  
  if (i == 0)
  {
    label_box = xpm_label_box(window, book_open_xpm, name, i);
  }else{
    label_box = xpm_label_box(window, book_closed_xpm, name, i);
  }
  gtk_notebook_insert_page (GTK_NOTEBOOK (notebook), box, label_box, i);
  gtk_widget_realize (text[i]);
  }
 num_pages = i;
/****************************************************************************/

#ifdef WITH_TEXT_BG_COLOR
  for(i=0;i<num_pages;i++)
    gdk_window_set_background (GTK_TEXT (text[i])->text_area, &text_background_color);
#endif

#ifdef WITH_TEXT_BG_IMAGE
  for(i=0;i<num_pages;i++)
    gdk_window_set_back_pixmap(GTK_TEXT(text[i])->text_area, text_background_xpm, 0);
#endif

  gtk_notebook_set_page (GTK_NOTEBOOK(notebook), 0);
  gtk_widget_grab_focus (text[0]);

  mkrcdir();
  for(i=0;i<num_pages;i++)readPage(i, text[i]);
      

  gtk_signal_connect (GTK_OBJECT (notebook), "switch_page",   
                      GTK_SIGNAL_FUNC (page_switch), NULL);

  gtk_widget_show(window);
  gtk_main ();
  return 0;
}
